summaryrefslogtreecommitdiffstats
path: root/tdeioslave/svn/svnhelper/kio_svn_helper.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdeioslave/svn/svnhelper/kio_svn_helper.cpp')
-rw-r--r--tdeioslave/svn/svnhelper/kio_svn_helper.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdeioslave/svn/svnhelper/kio_svn_helper.cpp b/tdeioslave/svn/svnhelper/kio_svn_helper.cpp
index 7f60861e..eba0634a 100644
--- a/tdeioslave/svn/svnhelper/kio_svn_helper.cpp
+++ b/tdeioslave/svn/svnhelper/kio_svn_helper.cpp
@@ -32,7 +32,7 @@
#include <tqpixmap.h>
#include <kmessagebox.h>
-#include "kio_svn_helper.h"
+#include "tdeio_svn_helper.h"
#include "subversioncheckout.h"
#include "subversionswitch.h"
#include "subversiondiff.h"
@@ -58,7 +58,7 @@ SvnHelper::SvnHelper():TDEApplication() {
if (args->isSet("u")) {
kdDebug(7128) << "update " << list << endl;
KURL servURL = "svn+http://this_is_a_fake_URL_and_this_is_normal/";
//FIXME when 1.2 is out (move the loop inside kio_svn's ::update)
for ( TQValueListConstIterator<KURL> it = list.begin(); it != list.end() ; ++it ) {
TQByteArray parms;
TQDataStream s( parms, IO_WriteOnly );
@@ -275,10 +275,10 @@ static KCmdLineOptions options[] = {
};
int main(int argc, char **argv) {
- TDECmdLineArgs::init(argc, argv, "kio_svn_helper", I18N_NOOP("Subversion Helper"), "TDE frontend for SVN", "0.1");
+ TDECmdLineArgs::init(argc, argv, "tdeio_svn_helper", I18N_NOOP("Subversion Helper"), "TDE frontend for SVN", "0.1");
TDECmdLineArgs::addCmdLineOptions( options );
- TDEGlobal::locale()->setMainCatalogue("kio_svn");
+ TDEGlobal::locale()->setMainCatalogue("tdeio_svn");
TDEApplication::addCmdLineOptions();
if ( TDECmdLineArgs::parsedArgs()->count()==0 )
@@ -289,4 +289,4 @@ int main(int argc, char **argv) {
app->exec();
}
-#include "kio_svn_helper.moc"
+#include "tdeio_svn_helper.moc"
@@ -58,7 +58,7 @@ SvnHelper::SvnHelper():TDEApplication() {
kdDebug(7128) << "update " << list << endl;
KURL servURL = "svn+http://this_is_a_fake_URL_and_this_is_normal/";
- //FIXME when 1.2 is out (move the loop inside kio_svn's ::update)
+ //FIXME when 1.2 is out (move the loop inside tdeio_svn's ::update)
for ( TQValueListConstIterator<KURL> it = list.begin(); it != list.end() ; ++it ) {
TQByteArray parms;